@@ -35,7 +35,7 @@ test_that("testing udpipe", {
   cnlp_init_udpipe()
   anno <- cnlp_annotate(un, verbose=FALSE)
   expect_equal(names(anno), c("token", "document"))
-  expect_equal(names(anno$token), c("doc_id", "sid", "tid", "token", "lemma", "space_after", "upos", "xpos", "feats", "tid_source", "relation"))
+  expect_equal(names(anno$token), c("doc_id", "sid", "tid", "token", "token_with_ws", "lemma", "upos", "xpos", "feats", "tid_source", "relation"))
 })
 
 test_that("testing corenlp", {
